fixed instance loading forget to append basepath.. other path fixes (windows)
[csRadar.git] / csRadar.h
index 4192e555ff13a5f9343d11a210099e9d59c42459..c54c24fbeeec886e4b557f15257defb6e17503ad 100644 (file)
--- a/csRadar.h
+++ b/csRadar.h
@@ -60,10 +60,14 @@ struct csr_api
        float padding;
        u32 resolution;
        int write_txt;
-       char output_path[ 512 ];                // Full path eg. /home/harry/my_map.vmf
-       char vmf_name[ 128 ];                   // Just the base name eg. my_map
+       char output_path[ 512 ];        // Full path to output eg. /home/harry/output
+       char vmf_name[ 128 ];           // Just the base name eg. my_map
+       char vmf_folder[ 512 ];         // Just the folder to the map eg. /home/harry/
        EMSAA sampling_mode;
        
+       float min_z;
+       float max_z;
+       
        // Main API interface
        vmf_map *map;
        csr_target target;